@@ -336,15 +336,12 @@ sub blocks {
     @{ $obj->{BLOCKS} };
 }
 
-BEGIN {
-    $Data::Dumper::Terse = 1;
-}
 sub show_match_table {
-    my $i = 0;
-    for my $t (@{+shift}) {
-	my $m = Dumper($t);
-	$m =~ s/\s+(?!$)/ /gs;
-	printf STDERR "%d %s", $i++, $m;
+    my $table = shift;
+    local $Data::Dumper::Terse = 1;
+    while (my($i, $e) = each @$table) {
+	printf STDERR
+	    "%4d %s", $i++, Dumper($e) =~ s/\s+(?!$)/ /gsr;
     }
 }
 
